Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/twbs/bootstrap.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
path: root/nuget
diff options
context:
space:
mode:
authorSupergibbs <jesse.mandel@gmail.com>2015-06-26 19:15:12 +0300
committerSupergibbs <jesse.mandel@gmail.com>2015-06-26 19:17:24 +0300
commit2e59d177aab3c80a27bca60f5c312b87b325f454 (patch)
treec1098903b1d5228da72ac4b18c4bb491c3f23d38 /nuget
parent95013f7d6d1963dd23bfbc2e9a8d02ac4ebf5efa (diff)
Cleaner version parsing
Changed LESS to Less and author to Twitter, Inc.
Diffstat (limited to 'nuget')
-rw-r--r--nuget/MyGet.ps15
-rw-r--r--nuget/bootstrap.less.nuspec6
-rw-r--r--nuget/bootstrap.nuspec4
3 files changed, 7 insertions, 8 deletions
diff --git a/nuget/bootstrap.less.nuspec b/nuget/bootstrap.less.nuspec
index 72aba82feb..7d69099f3a 100644
--- a/nuget/bootstrap.less.nuspec
+++ b/nuget/bootstrap.less.nuspec
@@ -3,12 +3,12 @@
<metadata>
<id>bootstrap.less</id>
<version>3.3</version>
- <title>Bootstrap LESS</title>
- <authors>Mark Otto,Jacob Thornton</authors>
+ <title>Bootstrap Less</title>
+ <authors>Twitter, Inc.</authors>
<owners>bootstrap</owners>
<description>The most popular front-end framework for developing responsive, mobile first projects on the web.</description>
<releaseNotes>http://blog.getbootstrap.com</releaseNotes>
- <summary>Bootstrap framework in LESS. Includes fonts and javascript</summary>
+ <summary>Bootstrap framework in Less. Includes fonts and JavaScript</summary>
<language>en-us</language>
<projectUrl>http://getbootstrap.com</projectUrl>
<iconUrl>http://getbootstrap.com/apple-touch-icon.png</iconUrl>
diff --git a/nuget/bootstrap.nuspec b/nuget/bootstrap.nuspec
index 1dee303bc5..3f1e211f84 100644
--- a/nuget/bootstrap.nuspec
+++ b/nuget/bootstrap.nuspec
@@ -4,11 +4,11 @@
<id>bootstrap</id>
<version>3.3</version>
<title>Bootstrap CSS</title>
- <authors>Mark Otto,Jacob Thornton</authors>
+ <authors>Twitter, Inc.</authors>
<owners>bootstrap</owners>
<description>The most popular front-end framework for developing responsive, mobile first projects on the web.</description>
<releaseNotes>http://blog.getbootstrap.com</releaseNotes>
- <summary>Bootstrap framework in CSS. Includes fonts and javascript</summary>
+ <summary>Bootstrap framework in CSS. Includes fonts and JavaScript</summary>
<language>en-us</language>
<projectUrl>http://getbootstrap.com</projectUrl>
<iconUrl>http://getbootstrap.com/apple-touch-icon.png</iconUrl>
diff --git a/nuget/MyGet.ps1 b/nuget/MyGet.ps1
index b3d9c8f778..ad17dea91f 100644
--- a/nuget/MyGet.ps1
+++ b/nuget/MyGet.ps1
@@ -1,8 +1,7 @@
$nuget = $env:NuGet
-#parse the version number out of the Jekyll _config.yml
-$yaml = (Select-String $env:SourcesPath\_config.yml -pattern "current_version").ToString().Split(" ");
-$bsversion = $yaml[$yaml.Length - 1]
+#parse the version number out of package.json
+$bsversion = ((Get-Content $env:SourcesPath\package.json) -join "`n" | ConvertFrom-Json).version
#create packages
& $nuget pack "nuget\bootstrap.nuspec" -Verbosity detailed -NonInteractive -NoPackageAnalysis -BasePath $env:SourcesPath -Version $bsversion